from setuptools import setup

setup(name='Sergi0',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['Sergi0'],
      author = 'Y.A alias sergio',
      zip_safe=False)
